## Dexy

Dexy is open source automation software with features especially designed for
documentation and reporting. More information at http://dexy.it

## Docs

The home page for all documentation is http://dexy.it/docs

Dexy's User Guide http://guide.dexy.it

Dexy's Developer Guide http://dexy.github.io/dexy

## Source

Dexy's source code is available from http://github.com/dexy/dexy

The 'stable' branch contains the most recent release of Dexy.
The 'develop' branch contains the most recent development version of Dexy.

From version 1.1 and up, Dexy will only run under Python 3.
(However Dexy can be used to document almost any programming language.)

## Tests

Dexy uses nose to run tests.

Additional Python package requirements for tests are in dev-requirements.txt

pip install -r dev-requirements.txt
